@@ -46,6 +46,7 @@
 #endif
 
 #include "misc.h"
+#include "fs_utils.h"
 #include "qinisettings.h"
 
 #define QBT_REALM "Web UI Access"
@@ -185,7 +186,7 @@ public:
     QString save_path = value(QString::fromUtf8("Preferences/Downloads/SavePath")).toString();
     if (!save_path.isEmpty())
       return save_path;
-    return misc::QDesktopServicesDownloadLocation();
+    return fsutils::QDesktopServicesDownloadLocation();
   }
 
   void setSavePath(const QString &save_path) {
@@ -209,7 +210,6 @@ public:
     setValue(QString::fromUtf8("Preferences/Downloads/TempPath"), path);
   }
 
-#if LIBTORRENT_VERSION_MINOR > 14
   bool useIncompleteFilesExtension() const {
     return value(QString::fromUtf8("Preferences/Downloads/UseIncompleteExtension"), false).toBool();
   }
@@ -217,7 +217,6 @@ public:
   void useIncompleteFilesExtension(bool enabled) {
     setValue(QString::fromUtf8("Preferences/Downloads/UseIncompleteExtension"), enabled);
   }
-#endif
 
   bool appendTorrentLabel() const {
     return value(QString::fromUtf8("Preferences/Downloads/AppendLabel"), false).toBool();
@@ -244,11 +243,11 @@ public:
   }
 
   bool useAdditionDialog() const {
-    return value(QString::fromUtf8("Preferences/Downloads/AdditionDialog"), false).toBool();
+    return value(QString::fromUtf8("Preferences/Downloads/NewAdditionDialog"), true).toBool();
   }
 
   void useAdditionDialog(bool b) {
-    setValue("Preferences/Downloads/AdditionDialog", b);
+    setValue("Preferences/Downloads/NewAdditionDialog", b);
   }
 
   bool addTorrentsInPause() const {
@@ -286,7 +285,7 @@ public:
 
   void setExportDir(QString path) {
     path = path.trimmed();
-    if(path.isEmpty())
+    if (path.isEmpty())
       path = QString();
     setValue(QString::fromUtf8("Preferences/Downloads/TorrentExport"), path);
   }
@@ -385,7 +384,7 @@ public:
   }
 
   void setGlobalDownloadLimit(int limit) {
-    if(limit <= 0) limit = -1;
+    if (limit <= 0) limit = -1;
     setValue("Preferences/Connection/GlobalDLLimit", limit);
   }
 
@@ -394,31 +393,31 @@ public:
   }
 
   void setGlobalUploadLimit(int limit) {
-    if(limit <= 0) limit = -1;
+    if (limit <= 0) limit = -1;
     setValue("Preferences/Connection/GlobalUPLimit", limit);
   }
 
   int getAltGlobalDownloadLimit() const {
     int ret = value(QString::fromUtf8("Preferences/Connection/GlobalDLLimitAlt"), 10).toInt();
-    if(ret <= 0)
+    if (ret <= 0)
       ret = 10;
     return ret;
   }
 
   void setAltGlobalDownloadLimit(int limit) {
-    if(limit <= 0) limit = -1;
+    if (limit <= 0) limit = -1;
     setValue("Preferences/Connection/GlobalDLLimitAlt", limit);
   }
 
   int getAltGlobalUploadLimit() const {
     int ret = value(QString::fromUtf8("Preferences/Connection/GlobalUPLimitAlt"), 10).toInt();
-    if(ret <= 0)
+    if (ret <= 0)
       ret = 10;
     return ret;
   }
 
   void setAltGlobalUploadLimit(int limit) {
-    if(limit <= 0) limit = -1;
+    if (limit <= 0) limit = -1;
     setValue("Preferences/Connection/GlobalUPLimitAlt", limit);
   }
 
@@ -529,7 +528,7 @@ public:
   }
 
   void setMaxConnecs(int val) {
-    if(val <= 0) val = -1;
+    if (val <= 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Bittorrent/MaxConnecs"), val);
   }
 
@@ -538,7 +537,7 @@ public:
   }
 
   void setMaxConnecsPerTorrent(int val) {
-    if(val <= 0) val = -1;
+    if (val <= 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Bittorrent/MaxConnecsPerTorrent"), val);
   }
 
@@ -547,7 +546,7 @@ public:
   }
 
   void setMaxUploadsPerTorrent(int val) {
-    if(val <= 0) val = -1;
+    if (val <= 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Bittorrent/MaxUploadsPerTorrent"), val);
   }
 
@@ -560,11 +559,11 @@ public:
   }
 
   bool isuTPRateLimited() const {
-    return value(QString::fromUtf8("Preferences/Bittorrent/uTP_rate_limiting"), false).toBool();
+    return value(QString::fromUtf8("Preferences/Bittorrent/uTP_rate_limited"), true).toBool();
   }
 
   void setuTPRateLimited(bool enabled) {
-    setValue("Preferences/Bittorrent/uTP_rate_limiting", enabled);
+    setValue("Preferences/Bittorrent/uTP_rate_limited", enabled);
   }
 
   bool isDHTEnabled() const {
@@ -650,7 +649,7 @@ public:
 
   void banIP(const QString &ip) {
     QStringList banned_ips = value(QString::fromUtf8("Preferences/IPFilter/BannedIPs"), QStringList()).toStringList();
-    if(!banned_ips.contains(ip)) {
+    if (!banned_ips.contains(ip)) {
       banned_ips << ip;
       setValue("Preferences/IPFilter/BannedIPs", banned_ips);
     }
@@ -693,7 +692,7 @@ public:
   }
 
   void setMaxActiveDownloads(int val) {
-    if(val < 0) val = -1;
+    if (val < 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Queueing/MaxActiveDownloads"), val);
   }
 
@@ -702,7 +701,7 @@ public:
   }
 
   void setMaxActiveUploads(int val) {
-    if(val < 0) val = -1;
+    if (val < 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Queueing/MaxActiveUploads"), val);
   }
 
@@ -711,7 +710,7 @@ public:
   }
 
   void setMaxActiveTorrents(int val) {
-    if(val < 0) val = -1;
+    if (val < 0) val = -1;
     setValue(QString::fromUtf8("Preferences/Queueing/MaxActiveTorrents"), val);
   }
 
@@ -767,7 +766,7 @@ public:
     // Get current password md5
     QString current_pass_md5 = getWebUiPassword();
     // Check if password did not change
-    if(current_pass_md5 == new_password) return;
+    if (current_pass_md5 == new_password) return;
     // Encode to md5 and save
     QCryptographicHash md5(QCryptographicHash::Md5);
     md5.addData(getWebUiUsername().toLocal8Bit()+":"+QBT_REALM+":");
@@ -778,7 +777,7 @@ public:
 
   QString getWebUiPassword() const {
     QString pass_ha1 = value("Preferences/WebUI/Password_ha1", "").toString();
-    if(pass_ha1.isEmpty()) {
+    if (pass_ha1.isEmpty()) {
       QCryptographicHash md5(QCryptographicHash::Md5);
       md5.addData(getWebUiUsername().toLocal8Bit()+":"+QBT_REALM+":");
       md5.addData("adminadmin");
@@ -994,12 +993,12 @@ public:
 
   int getMaxHalfOpenConnections() const {
     const int val = value(QString::fromUtf8("Preferences/Connection/MaxHalfOpenConnec"), 50).toInt();
-    if(val <= 0) return -1;
+    if (val <= 0) return -1;
     return val;
   }
 
   void setMaxHalfOpenConnections(int value) {
-    if(value <= 0) value = -1;
+    if (value <= 0) value = -1;
     setValue(QString::fromUtf8("Preferences/Connection/MaxHalfOpenConnec"), value);
   }
 
@@ -1029,7 +1028,6 @@ public:
   }
 #endif
 
-#if LIBTORRENT_VERSION_MINOR > 14
   bool isSuperSeedingEnabled() const {
     return value(QString::fromUtf8("Preferences/Advanced/SuperSeeding"), false).toBool();
   }
@@ -1045,9 +1043,8 @@ public:
   void setAnnounceToAllTrackers(bool enabled) {
     setValue(QString::fromUtf8("Preferences/Advanced/AnnounceToAllTrackers"), enabled);
   }
-#endif
 
-#if defined(Q_WS_X11) && (QT_VERSION >= QT_VERSION_CHECK(4,6,0))
+#if defined(Q_WS_X11)
   bool useSystemIconTheme() const {
     return value(QString::fromUtf8("Preferences/Advanced/useSystemIconTheme"), true).toBool();
   }
@@ -1063,14 +1060,14 @@ public:
 
   void addTorrentLabel(const QString& label) {
     QStringList labels = value("TransferListFilters/customLabels").toStringList();
-    if(!labels.contains(label))
+    if (!labels.contains(label))
       labels << label;
     setValue("TransferListFilters/customLabels", labels);
   }
 
   void removeTorrentLabel(const QString& label) {
     QStringList labels = value("TransferListFilters/customLabels").toStringList();
-    if(labels.contains(label))
+    if (labels.contains(label))
       labels.removeOne(label);
     setValue("TransferListFilters/customLabels", labels);
   }
@@ -1094,7 +1091,7 @@ public:
       const QString version = versions.takeLast();
       qDebug("Detected possible Python v%s location", qPrintable(version));
       QString path = reg_python.value(version+"/InstallPath/Default", "").toString().replace("/", "\\");
-      if(!path.isEmpty() && QDir(path).exists("python.exe")) {
+      if (!path.isEmpty() && QDir(path).exists("python.exe")) {
         qDebug("Found python.exe at %s", qPrintable(path));
         return path;
       }
@@ -1102,8 +1099,8 @@ public:
     // Fallback: Detect python from default locations
     QStringList supported_versions;
     supported_versions << "32" << "31" << "30" << "27" << "26" << "25";
-    foreach(const QString &v, supported_versions) {
-      if(QFile::exists("C:/Python"+v+"/python.exe")) {
+    foreach (const QString &v, supported_versions) {
+      if (QFile::exists("C:/Python"+v+"/python.exe")) {
         reg_python.setValue(v[0]+"."+v[1]+"/InstallPath/Default", QString("C:\\Python"+v));
         return "C:\\Python"+v;
       }
@@ -1121,7 +1118,7 @@ public:
 
   static bool isTorrentFileAssocSet() {
     QSettings settings("HKEY_CLASSES_ROOT", QIniSettings::NativeFormat);
-    if(settings.value(".torrent/Default").toString() != "qBittorrent") {
+    if (settings.value(".torrent/Default").toString() != "qBittorrent") {
       qDebug(".torrent != qBittorrent");
       return false;
     }
@@ -1129,15 +1126,15 @@ public:
     QString shell_command = settings.value("qBittorrent/shell/open/command/Default", "").toString();
     qDebug("Shell command is: %s", qPrintable(shell_command));
     QRegExp exe_reg("\"([^\"]+)\".*");
-    if(exe_reg.indexIn(shell_command) < 0)
+    if (exe_reg.indexIn(shell_command) < 0)
       return false;
     QString assoc_exe = exe_reg.cap(1);
     qDebug("exe: %s", qPrintable(assoc_exe));
-    if(assoc_exe.compare(qApp->applicationFilePath().replace("/", "\\"), Qt::CaseInsensitive) != 0)
+    if (assoc_exe.compare(qApp->applicationFilePath().replace("/", "\\"), Qt::CaseInsensitive) != 0)
       return false;
     // Icon
     const QString icon_str = "\""+qApp->applicationFilePath().replace("/", "\\")+"\",1";
-    if(settings.value("qBittorrent/DefaultIcon/Default", icon_str).toString().compare(icon_str, Qt::CaseInsensitive) != 0)
+    if (settings.value("qBittorrent/DefaultIcon/Default", icon_str).toString().compare(icon_str, Qt::CaseInsensitive) != 0)
       return false;
 
     return true;
@@ -1149,11 +1146,11 @@ public:
     // Check magnet link assoc
     QRegExp exe_reg("\"([^\"]+)\".*");
     QString shell_command = settings.value("Magnet/shell/open/command/Default", "").toString();
-    if(exe_reg.indexIn(shell_command) < 0)
+    if (exe_reg.indexIn(shell_command) < 0)
       return false;
     QString assoc_exe = exe_reg.cap(1);
     qDebug("exe: %s", qPrintable(assoc_exe));
-    if(assoc_exe.compare(qApp->applicationFilePath().replace("/", "\\"), Qt::CaseInsensitive) != 0)
+    if (assoc_exe.compare(qApp->applicationFilePath().replace("/", "\\"), Qt::CaseInsensitive) != 0)
       return false;
     return true;
   }
