@@ -30,7 +30,6 @@
 
 #include <QStandardItemModel>
 #include <QHeaderView>
-#include <QCompleter>
 #include <QMessageBox>
 #include <QTemporaryFile>
 #include <QSystemTrayIcon>
@@ -51,37 +50,33 @@
 #include "searchengine.h"
 #include "qbtsession.h"
 #include "downloadthread.h"
+#include "fs_utils.h"
 #include "misc.h"
 #include "preferences.h"
 #include "searchlistdelegate.h"
 #include "qinisettings.h"
 #include "mainwindow.h"
 #include "iconprovider.h"
+#include "lineedit.h"
 
 #define SEARCHHISTORY_MAXSIZE 50
 
 /*SEARCH ENGINE START*/
-SearchEngine::SearchEngine(MainWindow *parent) : QWidget(parent), mp_mainWindow(parent) {
+SearchEngine::SearchEngine(MainWindow* parent)
+  : QWidget(parent)
+  , search_pattern(new LineEdit)
+  , mp_mainWindow(parent)
+{
   setupUi(this);
+  searchBarLayout->insertWidget(0, search_pattern);
+  connect(search_pattern, SIGNAL(returnPressed()), search_button, SLOT(click()));
   // Icons
   search_button->setIcon(IconProvider::instance()->getIcon("edit-find"));
   download_button->setIcon(IconProvider::instance()->getIcon("download"));
   goToDescBtn->setIcon(IconProvider::instance()->getIcon("application-x-mswinurl"));
   enginesButton->setIcon(IconProvider::instance()->getIcon("preferences-system-network"));
-  // new qCompleter to the search pattern
-  startSearchHistory();
-  createCompleter();
-#if (QT_VERSION >= QT_VERSION_CHECK(4,5,0))
   tabWidget->setTabsClosable(true);
   connect(tabWidget, SIGNAL(tabCloseRequested(int)), this, SLOT(closeTab(int)));
-#else
-  // Add close tab button
-  closeTab_button = new QPushButton();
-  closeTab_button->setIcon(IconProvider::instance()->getIcon("tab-close"));
-  closeTab_button->setFlat(true);
-  tabWidget->setCornerWidget(closeTab_button);
-  connect(closeTab_button, SIGNAL(clicked()), this, SLOT(closeTab_button_clicked()));
-#endif
   // Boolean initialization
   search_stopped = false;
   // Creating Search Process
@@ -106,7 +101,7 @@ SearchEngine::SearchEngine(MainWindow *parent) : QWidget(parent), mp_mainWindow(
         );
   // Fill in category combobox
   fillCatCombobox();
-  connect(search_pattern, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(displayPatternContextMenu(QPoint)));
+
   connect(search_pattern, SIGNAL(textEdited(QString)), this, SLOT(searchTextEdited(QString)));
 }
 
@@ -114,7 +109,7 @@ void SearchEngine::fillCatCombobox() {
   comboCategory->clear();
   comboCategory->addItem(full_cat_names["all"], QVariant("all"));
   QStringList supported_cat = supported_engines->supportedCategories();
-  foreach(QString cat, supported_cat) {
+  foreach (QString cat, supported_cat) {
     qDebug("Supported category: %s", qPrintable(cat));
     comboCategory->addItem(full_cat_names[cat], QVariant(cat));
   }
@@ -123,10 +118,10 @@ void SearchEngine::fillCatCombobox() {
 #ifdef Q_WS_WIN
 bool SearchEngine::addPythonPathToEnv() {
   QString python_path = Preferences::getPythonPath();
-  if(!python_path.isEmpty()) {
+  if (!python_path.isEmpty()) {
     // Add it to PATH envvar
     QString path_envar = QString::fromLocal8Bit(qgetenv("PATH").constData());
-    if(path_envar.isNull()) {
+    if (path_envar.isNull()) {
       path_envar = "";
     }
     path_envar = python_path+";"+path_envar;
@@ -143,7 +138,7 @@ void SearchEngine::installPython() {
   DownloadThread *pydownloader = new DownloadThread(this);
   connect(pydownloader, SIGNAL(downloadFinished(QString,QString)), this, SLOT(pythonDownloadSuccess(QString,QString)));
   connect(pydownloader, SIGNAL(downloadFailure(QString,QString)), this, SLOT(pythonDownloadFailure(QString,QString)));
-  pydownloader->downloadUrl("http://python.org/ftp/python/2.7.2/python-2.7.2.msi");
+  pydownloader->downloadUrl("http://python.org/ftp/python/2.7.3/python-2.7.3.msi");
 }
 
 void SearchEngine::pythonDownloadSuccess(QString url, QString file_path) {
@@ -162,13 +157,13 @@ void SearchEngine::pythonDownloadSuccess(QString url, QString file_path) {
   qDebug("Setup should be complete!");
   // Reload search engine
   has_python = addPythonPathToEnv();
-  if(has_python) {
+  if (has_python) {
     supported_engines->update();
     // Launch the search again
     on_search_button_clicked();
   }
   // Delete temp file
-  misc::safeRemove(file_path+".msi");
+  QFile::remove(file_path+".msi");
 }
 
 void SearchEngine::pythonDownloadFailure(QString url, QString error) {
@@ -183,13 +178,11 @@ QString SearchEngine::selectedCategory() const {
   return comboCategory->itemData(comboCategory->currentIndex()).toString();
 }
 
-SearchEngine::~SearchEngine(){
+SearchEngine::~SearchEngine() {
   qDebug("Search destruction");
-  // save the searchHistory for later uses
-  saveSearchHistory();
   searchProcess->kill();
   searchProcess->waitForFinished();
-  foreach(QProcess *downloader, downloaders) {
+  foreach (QProcess *downloader, downloaders) {
     // Make sure we disconnect the SIGNAL/SLOT first
     // To avoid qreal free
     downloader->disconnect();
@@ -197,67 +190,18 @@ SearchEngine::~SearchEngine(){
     downloader->waitForFinished();
     delete downloader;
   }
-#if QT_VERSION < 0x040500
-  delete closeTab_button;
-#endif
+  delete search_pattern;
   delete searchTimeout;
   delete searchProcess;
   delete supported_engines;
-  if(searchCompleter)
-    delete searchCompleter;
-}
-
-void SearchEngine::displayPatternContextMenu(QPoint) {
-  QMenu myMenu(this);
-  QAction cutAct(IconProvider::instance()->getIcon("edit-cut"), tr("Cut"), &myMenu);
-  QAction copyAct(IconProvider::instance()->getIcon("edit-copy"), tr("Copy"), &myMenu);
-  QAction pasteAct(IconProvider::instance()->getIcon("edit-paste"), tr("Paste"), &myMenu);
-  QAction clearAct(IconProvider::instance()->getIcon("edit-clear"), tr("Clear field"), &myMenu);
-  QAction clearHistoryAct(IconProvider::instance()->getIcon("edit-clear-history"), tr("Clear completion history"), &myMenu);
-  bool hasCopyAct = false;
-  if(search_pattern->hasSelectedText()) {
-    myMenu.addAction(&cutAct);
-    myMenu.addAction(&copyAct);
-    hasCopyAct = true;
-  }
-  if(qApp->clipboard()->mimeData()->hasText()) {
-    myMenu.addAction(&pasteAct);
-    hasCopyAct = true;
-  }
-  if(hasCopyAct)
-    myMenu.addSeparator();
-  myMenu.addAction(&clearHistoryAct);
-  myMenu.addAction(&clearAct);
-  QAction *act = myMenu.exec(QCursor::pos());
-  if(act != 0) {
-    if(act == &clearHistoryAct) {
-      // Ask for confirmation
-      if(QMessageBox::question(this, tr("Confirmation"), tr("Are you sure you want to clear the history?"), QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes) {
-        // Clear history
-        searchHistory.setStringList(QStringList());
-      }
-    }
-    else if (act == &pasteAct) {
-      search_pattern->paste();
-    }
-    else if (act == &cutAct) {
-      search_pattern->cut();
-    }
-    else if (act == &copyAct) {
-      search_pattern->copy();
-    }
-    else if (act == &clearAct) {
-      search_pattern->clear();
-    }
-  }
 }
 
 void SearchEngine::tab_changed(int t)
 {//when we switch from a tab that is not empty to another that is empty the download button 
   //doesn't have to be available
-  if(t>-1)
+  if (t>-1)
   {//-1 = no more tab
-    if(all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel()->rowCount()) {
+    if (all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel()->rowCount()) {
       download_button->setEnabled(true);
       goToDescBtn->setEnabled(true);
     } else {
@@ -272,18 +216,6 @@ void SearchEngine::on_enginesButton_clicked() {
   connect(dlg, SIGNAL(enginesChanged()), this, SLOT(fillCatCombobox()));
 }
 
-// get the last searchs from a QIniSettings to a QStringList
-void SearchEngine::startSearchHistory(){
-  QIniSettings settings("qBittorrent", "qBittorrent");
-  searchHistory.setStringList(settings.value("Search/searchHistory",QStringList()).toStringList());
-}
-
-// Save the history list into the QIniSettings for the next session
-void SearchEngine::saveSearchHistory() {
-  QIniSettings settings("qBittorrent", "qBittorrent");
-  settings.setValue("Search/searchHistory",searchHistory.stringList());
-}
-
 void SearchEngine::searchTextEdited(QString) {
   // Enable search button
   search_button->setText(tr("Search"));
@@ -294,10 +226,10 @@ void SearchEngine::giveFocusToSearchInput() {
 }
 
 // Function called when we click on search button
-void SearchEngine::on_search_button_clicked(){
+void SearchEngine::on_search_button_clicked() {
 #ifdef Q_WS_WIN
-  if(!has_python) {
-    if(QMessageBox::question(this, tr("Missing Python Interpreter"),
+  if (!has_python) {
+    if (QMessageBox::question(this, tr("Missing Python Interpreter"),
                              tr("Python 2.x is required to use the search engine but it does not seem to be installed.\nDo you want to install it now?"),
                              QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes) {
       // Download and Install Python
@@ -306,17 +238,17 @@ void SearchEngine::on_search_button_clicked(){
     return;
   }
 #endif
-  if(searchProcess->state() != QProcess::NotRunning){
+  if (searchProcess->state() != QProcess::NotRunning) {
 #ifdef Q_WS_WIN
     searchProcess->kill();
 #else
     searchProcess->terminate();
 #endif
     search_stopped = true;
-    if(searchTimeout->isActive()) {
+    if (searchTimeout->isActive()) {
       searchTimeout->stop();
     }
-    if(search_button->text() != tr("Search")) {
+    if (search_button->text() != tr("Search")) {
       search_button->setText(tr("Search"));
       return;
     }
@@ -327,7 +259,7 @@ void SearchEngine::on_search_button_clicked(){
 
   const QString pattern = search_pattern->text().trimmed();
   // No search pattern entered
-  if(pattern.isEmpty()){
+  if (pattern.isEmpty()) {
     QMessageBox::critical(0, tr("Empty search pattern"), tr("Please type a search pattern first"));
     return;
   }
@@ -339,24 +271,11 @@ void SearchEngine::on_search_button_clicked(){
   tabName.replace(QRegExp("&{1}"), "&&");
   tabWidget->addTab(currentSearchTab, tabName);
   tabWidget->setCurrentWidget(currentSearchTab);
-#if QT_VERSION < 0x040500
-  closeTab_button->setEnabled(true);
-#endif
-  // if the pattern is not in the pattern
-  QStringList wordList = searchHistory.stringList();
-  if(wordList.indexOf(pattern) == -1){
-    //update the searchHistory list
-    wordList.append(pattern);
-    // verify the max size of the history
-    if(wordList.size() > SEARCHHISTORY_MAXSIZE)
-      wordList = wordList.mid(wordList.size()/2);
-    searchHistory.setStringList(wordList);
-  }
 
   // Getting checked search engines
   QStringList params;
   search_stopped = false;
-  params << misc::searchEngineLocation()+QDir::separator()+"nova2.py";
+  params << fsutils::searchEngineLocation()+QDir::separator()+"nova2.py";
   params << supported_engines->enginesEnabled().join(",");
   qDebug("Search with category: %s", qPrintable(selectedCategory()));
   params << selectedCategory();
@@ -372,23 +291,15 @@ void SearchEngine::on_search_button_clicked(){
   searchTimeout->start(180000); // 3min
 }
 
-void SearchEngine::createCompleter() {
-  if(searchCompleter)
-    delete searchCompleter;
-  searchCompleter = new QCompleter(&searchHistory);
-  searchCompleter->setCaseSensitivity(Qt::CaseInsensitive);
-  search_pattern->setCompleter(searchCompleter);
-}
-
 void SearchEngine::propagateSectionResized(int index, int , int newsize) {
-  foreach(SearchTab * tab, all_tab) {
+  foreach (SearchTab * tab, all_tab) {
     tab->getCurrentTreeView()->setColumnWidth(index, newsize);
   }
   saveResultsColumnsWidth();
 }
 
 void SearchEngine::saveResultsColumnsWidth() {
-  if(all_tab.size() > 0) {
+  if (all_tab.size() > 0) {
     QTreeView* treeview = all_tab.first()->getCurrentTreeView();
     QIniSettings settings("qBittorrent", "qBittorrent");
     QStringList width_list;
@@ -396,14 +307,14 @@ void SearchEngine::saveResultsColumnsWidth() {
     short nbColumns = all_tab.first()->getCurrentSearchListModel()->columnCount();
 
     QString line = settings.value("SearchResultsColsWidth", QString()).toString();
-    if(!line.isEmpty()) {
+    if (!line.isEmpty()) {
       width_list = line.split(' ');
     }
-    for(short i=0; i<nbColumns; ++i){
-      if(treeview->columnWidth(i)<1 && width_list.size() == nbColumns && width_list.at(i).toInt()>=1) {
+    for (short i=0; i<nbColumns; ++i) {
+      if (treeview->columnWidth(i)<1 && width_list.size() == nbColumns && width_list.at(i).toInt()>=1) {
         // load the former width
         new_width_list << width_list.at(i);
-      } else if(treeview->columnWidth(i)>=1) {
+      } else if (treeview->columnWidth(i)>=1) {
         // usual case, save the current width
         new_width_list << QString::number(treeview->columnWidth(i));
       } else {
@@ -417,11 +328,12 @@ void SearchEngine::saveResultsColumnsWidth() {
 }
 
 void SearchEngine::downloadTorrent(QString engine_url, QString torrent_url) {
-  if(torrent_url.startsWith("bc://bt/", Qt::CaseInsensitive)) {
+  if (torrent_url.startsWith("bc://bt/", Qt::CaseInsensitive)) {
     qDebug("Converting bc link to magnet link");
     torrent_url = misc::bcLinkToMagnet(torrent_url);
   }
-  if(torrent_url.startsWith("magnet:")) {
+  qDebug() << Q_FUNC_INFO << torrent_url;
+  if (torrent_url.startsWith("magnet:")) {
     QStringList urls;
     urls << torrent_url;
     mp_mainWindow->downloadFromURLList(urls);
@@ -431,7 +343,7 @@ void SearchEngine::downloadTorrent(QString engine_url, QString torrent_url) {
     connect(downloadProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(downloadFinished(int,QProcess::ExitStatus)));
     downloaders << downloadProcess;
     QStringList params;
-    params << misc::searchEngineLocation()+QDir::separator()+"nova2dl.py";
+    params << fsutils::searchEngineLocation()+QDir::separator()+"nova2dl.py";
     params << engine_url;
     params << torrent_url;
     // Launch search
@@ -439,7 +351,7 @@ void SearchEngine::downloadTorrent(QString engine_url, QString torrent_url) {
   }
 }
 
-void SearchEngine::searchStarted(){
+void SearchEngine::searchStarted() {
   // Update SearchEngine widgets
   search_status->setText(tr("Searching..."));
   search_status->repaint();
@@ -449,28 +361,28 @@ void SearchEngine::searchStarted(){
 // search Qprocess return output as soon as it gets new
 // stuff to read. We split it into lines and add each
 // line to search results calling appendSearchResult().
-void SearchEngine::readSearchOutput(){
+void SearchEngine::readSearchOutput() {
   QByteArray output = searchProcess->readAllStandardOutput();
   output.replace("\r", "");
   QList<QByteArray> lines_list = output.split('\n');
-  if(!search_result_line_truncated.isEmpty()){
+  if (!search_result_line_truncated.isEmpty()) {
     QByteArray end_of_line = lines_list.takeFirst();
     lines_list.prepend(search_result_line_truncated+end_of_line);
   }
   search_result_line_truncated = lines_list.takeLast().trimmed();
-  foreach(const QByteArray &line, lines_list){
+  foreach (const QByteArray &line, lines_list) {
     appendSearchResult(QString::fromUtf8(line));
   }
-  if(currentSearchTab)
+  if (currentSearchTab)
     currentSearchTab->getCurrentLabel()->setText(tr("Results")+QString::fromUtf8(" <i>(")+QString::number(nb_search_results)+QString::fromUtf8(")</i>:"));
 }
 
 void SearchEngine::downloadFinished(int exitcode, QProcess::ExitStatus) {
   QProcess *downloadProcess = (QProcess*)sender();
-  if(exitcode == 0) {
+  if (exitcode == 0) {
     QString line = QString::fromUtf8(downloadProcess->readAllStandardOutput()).trimmed();
     QStringList parts = line.split(' ');
-    if(parts.size() == 2) {
+    if (parts.size() == 2) {
       QString path = parts[0];
       QString url = parts[1];
       QBtSession::instance()->processDownloadedFile(url, path);
@@ -481,16 +393,22 @@ void SearchEngine::downloadFinished(int exitcode, QProcess::ExitStatus) {
   delete downloadProcess;
 }
 
+static void removePythonScriptIfExists(const QString& script_path)
+{
+    fsutils::forceRemove(script_path);
+    fsutils::forceRemove(script_path+"c");
+}
+
 // Update nova.py search plugin if necessary
 void SearchEngine::updateNova() {
   qDebug("Updating nova");
   // create nova directory if necessary
-  QDir search_dir(misc::searchEngineLocation());
+  QDir search_dir(fsutils::searchEngineLocation());
   QString nova_folder = misc::pythonVersion() >= 3 ? "nova3" : "nova";
   QFile package_file(search_dir.absoluteFilePath("__init__.py"));
   package_file.open(QIODevice::WriteOnly | QIODevice::Text);
   package_file.close();
-  if(!search_dir.exists("engines")){
+  if (!search_dir.exists("engines")) {
     search_dir.mkdir("engines");
   }
   QFile package_file2(search_dir.absolutePath().replace("\\", "/")+"/engines/__init__.py");
@@ -498,119 +416,99 @@ void SearchEngine::updateNova() {
   package_file2.close();
   // Copy search plugin files (if necessary)
   QString filePath = search_dir.absoluteFilePath("nova2.py");
-  if(getPluginVersion(":/"+nova_folder+"/nova2.py") > getPluginVersion(filePath)) {
-    if(QFile::exists(filePath)) {
-      misc::safeRemove(filePath);
-      misc::safeRemove(filePath+"c");
-    }
+  if (getPluginVersion(":/"+nova_folder+"/nova2.py") > getPluginVersion(filePath)) {
+    removePythonScriptIfExists(filePath);
     QFile::copy(":/"+nova_folder+"/nova2.py", filePath);
   }
 
   filePath = search_dir.absoluteFilePath("nova2dl.py");
-  if(getPluginVersion(":/"+nova_folder+"/nova2dl.py") > getPluginVersion(filePath)) {
-    if(QFile::exists(filePath)){
-      misc::safeRemove(filePath);
-      misc::safeRemove(filePath+"c");
-    }
+  if (getPluginVersion(":/"+nova_folder+"/nova2dl.py") > getPluginVersion(filePath)) {
+    removePythonScriptIfExists(filePath);
     QFile::copy(":/"+nova_folder+"/nova2dl.py", filePath);
   }
 
   filePath = search_dir.absoluteFilePath("novaprinter.py");
-  if(getPluginVersion(":/"+nova_folder+"/novaprinter.py") > getPluginVersion(filePath)) {
-    if(QFile::exists(filePath)){
-      misc::safeRemove(filePath);
-      misc::safeRemove(filePath+"c");
-    }
+  if (getPluginVersion(":/"+nova_folder+"/novaprinter.py") > getPluginVersion(filePath)) {
+    removePythonScriptIfExists(filePath);
     QFile::copy(":/"+nova_folder+"/novaprinter.py", filePath);
   }
 
   filePath = search_dir.absoluteFilePath("helpers.py");
-  if(getPluginVersion(":/"+nova_folder+"/helpers.py") > getPluginVersion(filePath)) {
-    if(QFile::exists(filePath)){
-      misc::safeRemove(filePath);
-      misc::safeRemove(filePath+"c");
-    }
+  if (getPluginVersion(":/"+nova_folder+"/helpers.py") > getPluginVersion(filePath)) {
+    removePythonScriptIfExists(filePath);
     QFile::copy(":/"+nova_folder+"/helpers.py", filePath);
   }
 
   filePath = search_dir.absoluteFilePath("socks.py");
-  if(QFile::exists(filePath)){
-    misc::safeRemove(filePath);
-    misc::safeRemove(filePath+"c");
-  }
+  removePythonScriptIfExists(filePath);
   QFile::copy(":/"+nova_folder+"/socks.py", filePath);
 
+  if (nova_folder == "nova") {
+    filePath = search_dir.absoluteFilePath("fix_encoding.py");
+    removePythonScriptIfExists(filePath);
+    QFile::copy(":/"+nova_folder+"/fix_encoding.py", filePath);
+  }
+
   if (nova_folder == "nova3") {
     filePath = search_dir.absoluteFilePath("sgmllib3.py");
-    if(QFile::exists(filePath)){
-      misc::safeRemove(filePath);
-      misc::safeRemove(filePath+"c");
-    }
+    removePythonScriptIfExists(filePath);
     QFile::copy(":/"+nova_folder+"/sgmllib3.py", filePath);
   }
-  QDir destDir(QDir(misc::searchEngineLocation()).absoluteFilePath("engines"));
+  QDir destDir(QDir(fsutils::searchEngineLocation()).absoluteFilePath("engines"));
   QDir shipped_subDir(":/"+nova_folder+"/engines/");
   QStringList files = shipped_subDir.entryList();
-  foreach(const QString &file, files){
+  foreach (const QString &file, files) {
     QString shipped_file = shipped_subDir.absoluteFilePath(file);
     // Copy python classes
-    if(file.endsWith(".py")) {
+    if (file.endsWith(".py")) {
       const QString dest_file = destDir.absoluteFilePath(file);
-      if(getPluginVersion(shipped_file) > getPluginVersion(dest_file) ) {
+      if (getPluginVersion(shipped_file) > getPluginVersion(dest_file) ) {
         qDebug("shipped %s is more recent then local plugin, updating...", qPrintable(file));
-        if(QFile::exists(dest_file)) {
-          qDebug("Removing old %s", qPrintable(dest_file));
-          misc::safeRemove(dest_file);
-          misc::safeRemove(dest_file+"c");
-        }
+        removePythonScriptIfExists(dest_file);
         qDebug("%s copied to %s", qPrintable(shipped_file), qPrintable(dest_file));
         QFile::copy(shipped_file, dest_file);
       }
     } else {
       // Copy icons
-      if(file.endsWith(".png")) {
-        if(!QFile::exists(destDir.absoluteFilePath(file))) {
+      if (file.endsWith(".png")) {
+        if (!QFile::exists(destDir.absoluteFilePath(file))) {
           QFile::copy(shipped_file, destDir.absoluteFilePath(file));
         }
       }
     }
   }
-#ifndef Q_WS_WIN
-  // Fix permissions
-  misc::chmod644(QDir(misc::searchEngineLocation()));
-#endif
 }
 
 // Slot called when search is Finished
 // Search can be finished for 3 reasons :
 // Error | Stopped by user | Finished normally
-void SearchEngine::searchFinished(int exitcode,QProcess::ExitStatus){
-  if(searchTimeout->isActive()) {
+void SearchEngine::searchFinished(int exitcode,QProcess::ExitStatus) {
+  if (searchTimeout->isActive()) {
     searchTimeout->stop();
   }
   QIniSettings settings("qBittorrent", "qBittorrent");
   bool useNotificationBalloons = settings.value("Preferences/General/NotificationBaloons", true).toBool();
-  if(useNotificationBalloons && mp_mainWindow->getCurrentTabWidget() != this) {
+  if (useNotificationBalloons && mp_mainWindow->getCurrentTabWidget() != this) {
     mp_mainWindow->showNotificationBaloon(tr("Search Engine"), tr("Search has finished"));
   }
-  if(exitcode){
+  if (exitcode) {
 #ifdef Q_WS_WIN
     search_status->setText(tr("Search aborted"));
 #else
     search_status->setText(tr("An error occured during search..."));
 #endif
   }else{
-    if(search_stopped){
+    if (search_stopped) {
       search_status->setText(tr("Search aborted"));
     }else{
-      if(no_search_results){
+      if (no_search_results) {
         search_status->setText(tr("Search returned no results"));
       }else{
         search_status->setText(tr("Search has finished"));
       }
     }
   }
-  if(currentSearchTab)
+  if (currentSearchTab)
     currentSearchTab->getCurrentLabel()->setText(tr("Results", "i.e: Search results")+QString::fromUtf8(" <i>(")+QString::number(nb_search_results)+QString::fromUtf8(")</i>:"));
   search_button->setText("Search");
 }
@@ -618,12 +516,12 @@ void SearchEngine::searchFinished(int exitcode,QProcess::ExitStatus){
 // SLOT to append one line to search results list
 // Line is in the following form :
 // file url | file name | file size | nb seeds | nb leechers | Search engine url
-void SearchEngine::appendSearchResult(const QString &line){
-  if(!currentSearchTab) {
-    if(searchProcess->state() != QProcess::NotRunning){
+void SearchEngine::appendSearchResult(const QString &line) {
+  if (!currentSearchTab) {
+    if (searchProcess->state() != QProcess::NotRunning) {
       searchProcess->terminate();
     }
-    if(searchTimeout->isActive()) {
+    if (searchTimeout->isActive()) {
       searchTimeout->stop();
     }
     search_stopped = true;
@@ -631,7 +529,7 @@ void SearchEngine::appendSearchResult(const QString &line){
   }
   const QStringList parts = line.split("|");
   const int nb_fields = parts.size();
-  if(nb_fields < NB_PLUGIN_COLUMNS-1){ //-1 because desc_link is optional
+  if (nb_fields < NB_PLUGIN_COLUMNS-1) { //-1 because desc_link is optional
     return;
   }
   Q_ASSERT(currentSearchTab);
@@ -646,20 +544,20 @@ void SearchEngine::appendSearchResult(const QString &line){
   cur_model->setData(cur_model->index(row, SIZE), parts.at(PL_SIZE).trimmed().toLongLong()); // Size
   bool ok = false;
   qlonglong nb_seeders = parts.at(PL_SEEDS).trimmed().toLongLong(&ok);
-  if(!ok || nb_seeders < 0) {
+  if (!ok || nb_seeders < 0) {
     cur_model->setData(cur_model->index(row, SEEDS), tr("Unknown")); // Seeders
   } else {
     cur_model->setData(cur_model->index(row, SEEDS), nb_seeders); // Seeders
   }
   qlonglong nb_leechers = parts.at(PL_LEECHS).trimmed().toLongLong(&ok);
-  if(!ok || nb_leechers < 0) {
+  if (!ok || nb_leechers < 0) {
     cur_model->setData(cur_model->index(row, LEECHS), tr("Unknown")); // Leechers
   } else {
     cur_model->setData(cur_model->index(row, LEECHS), nb_leechers); // Leechers
   }
   cur_model->setData(cur_model->index(row, ENGINE_URL), parts.at(PL_ENGINE_URL).trimmed()); // Engine URL
   // Description Link
-  if(nb_fields == NB_PLUGIN_COLUMNS)
+  if (nb_fields == NB_PLUGIN_COLUMNS)
     cur_model->setData(cur_model->index(row, DESC_LINK), parts.at(PL_DESC_LINK).trimmed());
 
   no_search_results = false;
@@ -669,57 +567,31 @@ void SearchEngine::appendSearchResult(const QString &line){
   goToDescBtn->setEnabled(true);
 }
 
-#if QT_VERSION >= 0x040500
 void SearchEngine::closeTab(int index) {
-  if(index == tabWidget->indexOf(currentSearchTab)) {
+  if (index == tabWidget->indexOf(currentSearchTab)) {
     qDebug("Deleted current search Tab");
-    if(searchProcess->state() != QProcess::NotRunning){
+    if (searchProcess->state() != QProcess::NotRunning) {
       searchProcess->terminate();
     }
-    if(searchTimeout->isActive()) {
+    if (searchTimeout->isActive()) {
       searchTimeout->stop();
     }
     search_stopped = true;
     currentSearchTab = 0;
   }
   delete all_tab.takeAt(index);
-  if(!all_tab.size()) {
+  if (!all_tab.size()) {
     download_button->setEnabled(false);
     goToDescBtn->setEnabled(false);
   }
 }
-#else
-// Clear search results list
-void SearchEngine::closeTab_button_clicked(){
-  if(all_tab.size()) {
-    qDebug("currentTab rank: %d", tabWidget->currentIndex());
-    qDebug("currentSearchTab rank: %d", tabWidget->indexOf(currentSearchTab));
-    if(tabWidget->currentIndex() == tabWidget->indexOf(currentSearchTab)) {
-      qDebug("Deleted current search Tab");
-      if(searchProcess->state() != QProcess::NotRunning){
-        searchProcess->terminate();
-      }
-      if(searchTimeout->isActive()) {
-        searchTimeout->stop();
-      }
-      search_stopped = true;
-      currentSearchTab = 0;
-    }
-    delete all_tab.takeAt(tabWidget->currentIndex());
-    if(!all_tab.size()) {
-      closeTab_button->setEnabled(false);
-      download_button->setEnabled(false);
-    }
-  }
-}
-#endif
 
 // Download selected items in search results list
-void SearchEngine::on_download_button_clicked(){
+void SearchEngine::on_download_button_clicked() {
   //QModelIndexList selectedIndexes = currentSearchTab->getCurrentTreeView()->selectionModel()->selectedIndexes();
   QModelIndexList selectedIndexes = all_tab.at(tabWidget->currentIndex())->getCurrentTreeView()->selectionModel()->selectedIndexes();
-  foreach(const QModelIndex &index, selectedIndexes){
-    if(index.column() == NAME){
+  foreach (const QModelIndex &index, selectedIndexes) {
+    if (index.column() == NAME) {
       // Get Item url
       QSortFilterProxyModel* model = all_tab.at(tabWidget->currentIndex())->getCurrentSearchListProxy();
       QString torrent_url = model->data(model->index(index.row(), URL_COLUMN)).toString();
@@ -733,11 +605,11 @@ void SearchEngine::on_download_button_clicked(){
 void SearchEngine::on_goToDescBtn_clicked()
 {
   QModelIndexList selectedIndexes = all_tab.at(tabWidget->currentIndex())->getCurrentTreeView()->selectionModel()->selectedIndexes();
-  foreach(const QModelIndex &index, selectedIndexes){
-    if(index.column() == NAME) {
+  foreach (const QModelIndex &index, selectedIndexes) {
+    if (index.column() == NAME) {
       QSortFilterProxyModel* model = all_tab.at(tabWidget->currentIndex())->getCurrentSearchListProxy();
       const QString desc_url = model->data(model->index(index.row(), DESC_LINK)).toString();
-      if(!desc_url.isEmpty())
+      if (!desc_url.isEmpty())
         QDesktopServices::openUrl(QUrl::fromEncoded(desc_url.toUtf8()));
     }
   }
